package cn.com.qmth.mps.service.impl;

import java.util.HashMap;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.qmth.boot.core.exception.StatusException;
import com.qmth.boot.core.security.service.AuthorizationService;
import com.qmth.boot.tools.signature.SignatureType;
import com.qmth.boot.tools.uuid.FastUUID;

import cn.com.qmth.mps.bean.User;
import cn.com.qmth.mps.config.SysProperty;
import cn.com.qmth.mps.entity.UserEntity;
import cn.com.qmth.mps.enums.Role;
import cn.com.qmth.mps.service.AuthService;
import cn.com.qmth.mps.service.SessionService;
import cn.com.qmth.mps.service.UserService;
import cn.com.qmth.mps.util.ByteUtil;
import cn.com.qmth.mps.util.HttpUtil;
import cn.com.qmth.mps.util.SHA256;
import cn.com.qmth.mps.vo.AdminLoginVo;
import net.sf.json.JSONObject;

@Service
public class AuthServiceImpl implements AuthorizationService<User>, AuthService{
	private static String uri="https://api.weixin.qq.com/sns/jscode2session";
	@Autowired
	private UserService userService;
	@Autowired
	private SessionService sessionService;
	
	@Autowired
	private SysProperty sysProperty;
	@Override
	public AdminLoginVo loginWxApp(String wxappCode, String phone) {
		
		Map<String,String> params=new HashMap<>();
		params.put("appid", sysProperty.getWxappAppid());
		params.put("secret", sysProperty.getWxappSecret());
		params.put("js_code", wxappCode);
		params.put("grant_type", "authorization_code");
		String ret;
		try {
			ret=HttpUtil.httpActionGet(uri, null, params);
		} catch (Exception e) {
			throw new StatusException("登录失败",e);
		}
		JSONObject jo=JSONObject.fromObject(ret);
		if(jo.containsKey("errmsg")) {
			throw new StatusException("登录失败,"+jo.getString("errmsg"));
		}
		UserEntity userEntity=userService.getByLoginName(phone);
		if(userEntity==null) {
			throw new StatusException("该手机号不存在");
		}
		if(!userEntity.getEnable()) {
			throw new StatusException("该用户已禁用");
		}
		if(!userEntity.getRoleId().equals(Role.SECTION_LEADER.getId())) {
			throw new StatusException("该用户不是科组长");
		}
		User user = new User();
		user.setName(userEntity.getName());
		user.setSchoolId(userEntity.getSchoolId());
		user.setId(userEntity.getId());
		user.setRole(Role.getById(userEntity.getRoleId()));
		user.setAccessToken(FastUUID.get());
		user.buildKey();
		sessionService.userLogin(user);
		AdminLoginVo vo=new AdminLoginVo();
		vo.setAccessToken(user.getAccessToken());
		vo.setName(user.getName());
		vo.setSessionId(user.getSessionId());
		vo.setSchoolId(user.getSchoolId());
		vo.setRole(user.getRole());
		return vo;
	}
	
	@Override
	public AdminLoginVo loginAdmin(String loginName, String password) {
		UserEntity userEntity=userService.getByLoginName(loginName);
		if(userEntity==null) {
			throw new StatusException("账号不存在");
		}
		if(!userEntity.getEnable()) {
			throw new StatusException("该用户已禁用");
		}
		if(userEntity.getRoleId().equals(Role.SECTION_LEADER.getId())) {
			throw new StatusException("科组长无权限登录");
		}
		byte[] bytes = SHA256.encode(password);
		String encodePassword = ByteUtil.toHexAscii(bytes);
		if (!encodePassword.equals(userEntity.getPassword())) {
			throw new StatusException("密码错误");
		}
		User user = new User();
		user.setName(userEntity.getName());
		user.setSchoolId(userEntity.getSchoolId());
		user.setId(userEntity.getId());
		user.setRole(Role.getById(userEntity.getRoleId()));
		user.setAccessToken(FastUUID.get());
		user.buildKey();
		sessionService.userLogin(user);
		AdminLoginVo vo=new AdminLoginVo();
		vo.setAccessToken(user.getAccessToken());
		vo.setName(user.getName());
		vo.setSessionId(user.getSessionId());
		vo.setSchoolId(user.getSchoolId());
		vo.setRole(user.getRole());
		return vo;
	}

	@Override
	public void logout(User user) {
		sessionService.userLogout(user);
	}

    @Override
    public User findByIdentity(String identity, SignatureType type, String path) {
        User user = sessionService.getSessionUser(identity);
        return user;
    }

    @Override
    public boolean hasPermission(User user, String path) {
        sessionService.updateUserSession(user);
        return true;
    }


}
